@@ -1,5 +1,7 @@
 from time import sleep
-import serial
+from serial import Serial
+from serial.tools.list_ports import comports
+from serial import tools
 from . import kb_config
 
 ser = None
@@ -25,23 +27,28 @@ def read_line():
 def initialize_connection():
     global ser
     try:
-        ser = serial.Serial(kb_config.tty_name, kb_config.tty_rate, timeout=kb_config.tty_timeout)
+        print(f'Forbinder til micro:bit på: {kb_config.tty_name}')
+        ser = Serial(kb_config.tty_name, kb_config.tty_rate, timeout=kb_config.tty_timeout)
         ser.reset_input_buffer()
         ser.reset_output_buffer()
-        print()
-        print(f'Forbinder til micro:bit på: {kb_config.tty_name}')
         sleep(0.2)
         send_message('init')
         return ser
     except Exception as e:
         print()
-        print(
-            f"Der skete en fejl under forbindelse til seriel porten: {kb_config.tty_name}")
-        print("Tjek om microbit'en er forbundet, eller om portnavnet er korrekt.")
-        print()
-        print(type(e))
-        print('----')
+        print('-------------------------------------')
+        print("FEJL under etablering af forbindelse!")
         print(e.args)
+        print()
+        print("Tjek om microbit'en er forbundet, eller om portnavnet er korrekt.")
+        ports = comports()
+        if len(ports) > 0:
+            print()
+            print('Tilgængelige porte:')
+            for port in ports:
+                print(port)
+        print('-------------------------------------')
+        print()
         exit()
 
 def close_connection():
